@@ -1,4 +1,5 @@
 # Copyright (c) 2020 Red Hat, Inc.
+# Copyright Contributors to the Open Cluster Management project
 
 if ! jq --version > /dev/null 2>&1; then
   echo "Missing dependency: jq"
@@ -13,8 +14,14 @@ OCM_ROUTE=multicloud-console
 OCM_ADDRESS=https://`oc -n $OCM_NAMESPACE get route $OCM_ROUTE -o json | jq -r '.spec.host'`
 
 OAUTH2_CLIENT_ID=multicloudingress
-OAUTH2_CLIENT_SECRET=multicloudingresssecret
-OAUTH2_REDIRECT_URL=https://localhost:3001/multicloud/applications/auth/callback
+OAUTH2_CLIENT_SECRET=$(oc get OAuthClient $OAUTH2_CLIENT_ID -o json | jq -r '.secret')
+
+PROTOCOL=http
+if [[ ($serverKey || -f './sslcert/server.key') && ($serverCert || -f './sslcert/server.crt') ]]
+then
+  PROTOCOL=https
+fi
+OAUTH2_REDIRECT_URL=${PROTOCOL}://localhost:3001/multicloud/applications/auth/callback
 
 # Patch ingress with redirect URL
 REDIRECT_URIS=$(oc get OAuthClient $OAUTH2_CLIENT_ID -o json | jq -c "[.redirectURIs[], \"$OAUTH2_REDIRECT_URL\"] | unique")
