@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 
 'use strict'
 
@@ -25,23 +26,10 @@ import {
 import { updateResourceFilters, combineFilters } from '../../actions/filters'
 import { withRouter } from 'react-router-dom'
 import msgs from '../../../nls/platform.properties'
-import resources from '../../../lib/shared/resources'
-import {
-  renderRefreshTime,
-  startPolling,
-  stopPolling,
-  handleRefreshPropertiesChanged,
-  handleVisibilityChanged
-} from '../../shared/utils/refetch'
-import { refetchIntervalUpdate } from '../../actions/refetch'
 import { withLocale } from '../../providers/LocaleProvider'
-import { AcmAlert } from '@stolostron/ui-components'
+import { AcmAlert } from '@open-cluster-management/ui-components'
 import { Stack, StackItem } from '@patternfly/react-core'
 
-resources(() => {
-  require('../../../scss/resource-list.scss')
-})
-
 class ResourceList extends React.Component {
   constructor(props) {
     super(props)
@@ -62,37 +50,12 @@ class ResourceList extends React.Component {
 
     const { fetchTableResources } = this.props
     fetchTableResources([])
-
-    document.addEventListener('visibilitychange', this.onVisibilityChange)
-    startPolling(this, setInterval)
-  }
-
-  componentWillUnmount() {
-    stopPolling(this.state, clearInterval)
-    document.removeEventListener('visibilitychange', this.onVisibilityChange)
-    this.mutateFinished()
   }
 
   mutateFinished() {
     this.props.deleteSuccessFinished()
   }
 
-  onVisibilityChange = () => {
-    handleVisibilityChanged(this, clearInterval, setInterval)
-  };
-
-  componentDidUpdate(prevProps) {
-    handleRefreshPropertiesChanged(prevProps, this, clearInterval, setInterval)
-  }
-
-  reload() {
-    if (this.props.status === REQUEST_STATUS.DONE) {
-      this.setState({ xhrPoll: true })
-      const { fetchTableResources } = this.props
-      fetchTableResources([])
-    }
-  }
-
   render() {
     const {
       items,
@@ -105,8 +68,6 @@ class ResourceList extends React.Component {
       resourceType,
       err,
       children,
-      fetchTableResources,
-      refetchIntervalUpdateDispatch,
       page,
       changeTablePageFn,
       searchValue,
@@ -115,9 +76,6 @@ class ResourceList extends React.Component {
       sortTableFn
     } = this.props
 
-    const { isLoaded = true, isReloading = false } = fetchTableResources
-    const { timestamp = new Date().toString() } = this.state
-
     if (status === REQUEST_STATUS.ERROR && !this.state.xhrPoll) {
       //eslint-disable-next-line no-console
       console.error(err)
@@ -126,6 +84,7 @@ class ResourceList extends React.Component {
           title={msgs.get('error.default.description', locale)}
           variant="danger"
           noClose
+          isInline
         />
       )
     }
@@ -146,6 +105,7 @@ class ResourceList extends React.Component {
               locale
             )}
             variant="success"
+            isInline
           />
         </StackItem>
       )
@@ -158,7 +118,8 @@ class ResourceList extends React.Component {
           itemIds={itemIds}
           items={items}
           resourceType={resourceType}
-          tableActions={staticResourceData.tableActions}
+          tableActions={staticResourceData?.tableActions}
+          tableActionsResolver={staticResourceData?.tableActionsResolver}
           page={page}
           setPage={changeTablePageFn}
           search={searchValue}
@@ -172,13 +133,6 @@ class ResourceList extends React.Component {
 
     return (
       <div id="resource-list">
-        {renderRefreshTime(
-          refetchIntervalUpdateDispatch,
-          isLoaded,
-          isReloading,
-          timestamp,
-          locale
-        )}
         <Stack hasGutter>{stackItems}</Stack>
       </div>
     )
@@ -222,8 +176,7 @@ const mapStateToProps = (state, ownProps) => {
     err: state[typeListName].err,
     deleteStatus: state[typeListName].deleteStatus,
     deleteMsg: state[typeListName].deleteMsg,
-    forceReload: state[typeListName].forceReload,
-    refetch: state.refetch
+    forceReload: state[typeListName].forceReload
   }
 }
 
@@ -251,8 +204,7 @@ const mapDispatchToProps = (dispatch, ownProps) => {
       dispatch(updateResourceFilters(resourceType, selectedFilters))
     },
     deleteSuccessFinished: () =>
-      dispatch(delResourceSuccessFinished(ownProps.resourceType)),
-    refetchIntervalUpdateDispatch: data => dispatch(refetchIntervalUpdate(data))
+      dispatch(delResourceSuccessFinished(ownProps.resourceType))
   }
 }
 
@@ -269,7 +221,6 @@ ResourceList.propTypes = {
   locale: PropTypes.string,
   mainButton: PropTypes.object,
   page: PropTypes.number,
-  refetchIntervalUpdateDispatch: PropTypes.func,
   resourceType: PropTypes.object,
   searchTableFn: PropTypes.func,
   searchValue: PropTypes.string,
