@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import React from 'react'
@@ -14,7 +15,7 @@ import ResourceDetails from './ResourceDetails'
 import ResourceList from './ResourceList'
 import getResourceDefinitions from '../../definitions'
 import { makeGetVisibleTableItemsSelector } from '../../reducers/common'
-import Page from './Page'
+import { PageSection } from '@patternfly/react-core'
 
 const WrappedResourceList = props => (
   <div>
@@ -54,17 +55,15 @@ const typedResourcePageList = (resourceType, buttons, routes, modules) => {
 
     render() {
       return (
-        <Page>
-          <WrappedResourceList
-            {...this.props}
-            routes={routes}
-            resourceType={resourceType}
-            staticResourceData={staticResourceData}
-            getVisibleResources={getVisibleResources}
-            buttons={buttons}
-            modules={modules}
-          />
-        </Page>
+        <WrappedResourceList
+          {...this.props}
+          routes={routes}
+          resourceType={resourceType}
+          staticResourceData={staticResourceData}
+          getVisibleResources={getVisibleResources}
+          buttons={buttons}
+          modules={modules}
+        />
       )
     }
   }
@@ -82,7 +81,7 @@ const typedResourcePageDetails = (resourceType, buttons, routes, modules) => {
 
     render() {
       return (
-        <Page>
+        <PageSection>
           <WrappedResourceDetails
             {...this.props}
             routes={routes}
@@ -92,7 +91,7 @@ const typedResourcePageDetails = (resourceType, buttons, routes, modules) => {
             buttons={buttons}
             modules={modules}
           />
-        </Page>
+        </PageSection>
       )
     }
   }
