@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 'use strict'
 
 import _ from 'lodash'
@@ -20,14 +21,17 @@ import { canCallAction } from '../../../lib/client/access-helper'
 import {
   forceResourceReload,
   receiveDelResource,
-  delResourceSuccessFinished,
-  mutateResourceSuccessFinished,
+  clearSuccessFinished,
   getQueryStringForResource
 } from '../../actions/common'
 import { RESOURCE_TYPES } from '../../../lib/shared/constants'
 import resources from '../../../lib/shared/resources'
 import { withLocale } from '../../providers/LocaleProvider'
-import { AcmModal, AcmLoadingPage, AcmAlert } from '@stolostron/ui-components'
+import {
+  AcmModal,
+  AcmLoadingPage,
+  AcmAlert
+} from '@open-cluster-management/ui-components'
 import { Checkbox, Button, ModalVariant } from '@patternfly/react-core'
 import { ExclamationTriangleIcon } from '@patternfly/react-icons'
 
@@ -55,7 +59,8 @@ class RemoveResourceModal extends React.Component {
     if (this.props.data) {
       const { data } = this.props
       const kind = data.kind
-      const [group, version] = data.apiVersion.split('/')
+      const apiVersion = _.get(data, 'apiVersion', '')
+      const [group, version] = apiVersion.split('/')
       canCallAction(kind, 'delete', data.namespace, group, version).then(
         response => {
           const allowed = _.get(response, 'data.userAccess.allowed')
@@ -78,7 +83,7 @@ class RemoveResourceModal extends React.Component {
     try {
       const { resourceType, locale } = this.props
       const { canRemove } = this.state
-      if (resourceType.name === 'HCMApplication' && canRemove) {
+      if (resourceType.name === 'QueryApplications' && canRemove) {
         // Get application resources
         apolloClient.getApplication({ name, namespace }).then(response => {
           // Warning for application deployed by another application
@@ -252,14 +257,7 @@ class RemoveResourceModal extends React.Component {
       loading: true
     })
     // Remove previous success message if any
-    this.props.mutateSuccessFinished(RESOURCE_TYPES.HCM_CHANNELS)
-    this.props.mutateSuccessFinished(RESOURCE_TYPES.HCM_SUBSCRIPTIONS)
-    this.props.mutateSuccessFinished(RESOURCE_TYPES.HCM_PLACEMENT_RULES)
-    this.props.mutateSuccessFinished(RESOURCE_TYPES.QUERY_APPLICATIONS)
-    this.props.deleteSuccessFinished(RESOURCE_TYPES.HCM_CHANNELS)
-    this.props.deleteSuccessFinished(RESOURCE_TYPES.HCM_SUBSCRIPTIONS)
-    this.props.deleteSuccessFinished(RESOURCE_TYPES.HCM_PLACEMENT_RULES)
-    this.props.deleteSuccessFinished(RESOURCE_TYPES.QUERY_APPLICATIONS)
+    this.props.clearSuccessFinished()
     if (!data.name) {
       this.setState({
         errors: msgs.get('modal.errors.querying.resource', locale)
@@ -343,7 +341,7 @@ class RemoveResourceModal extends React.Component {
 
   modalBody = (name, label, locale) => {
     const { selected } = this.state
-    if (label.label === 'modal.remove-hcmapplication.label') {
+    if (label.label === 'modal.remove-queryapplications.label') {
       return selected.length > 0 ? (
         <div className="remove-app-modal-content">
           <div className="remove-app-modal-content-text">
@@ -406,19 +404,19 @@ class RemoveResourceModal extends React.Component {
         </div>
       ) : (
         <div className="remove-app-modal-content">
-          {msgs.get('modal.remove.confirm', [name], locale)}
+          {msgs.get('modal.remove.confirm', locale)}
           {this.renderSharedResources()}
         </div>
       )
     } else {
-      return msgs.get('modal.remove.confirm', [name], locale)
+      return msgs.get('modal.remove.confirm', locale)
     }
   };
 
   render() {
     const { label, locale, open } = this.props
     const { canRemove, name, loading, errors, warnings } = this.state
-    const heading = msgs.get(label.heading, locale)
+    const heading = msgs.get(label.heading, [name], locale)
     return (
       <div>
         <AcmModal
@@ -429,8 +427,9 @@ class RemoveResourceModal extends React.Component {
           showClose={true}
           onClose={this.handleClose.bind(this)}
           variant={ModalVariant.large}
+          titleIconVariant="warning"
           position="top"
-          positionOffset="200px"
+          positionOffset="225px"
           actions={[
             <Button
               key="confirm"
@@ -442,7 +441,7 @@ class RemoveResourceModal extends React.Component {
             </Button>,
             <Button
               key="cancel"
-              variant="secondary"
+              variant="link"
               onClick={this.handleClose.bind(this)}
             >
               {msgs.get('modal.button.cancel', locale)}
@@ -564,8 +563,8 @@ export const usedByOtherSubs = (
 }
 
 RemoveResourceModal.propTypes = {
+  clearSuccessFinished: PropTypes.func,
   data: PropTypes.object,
-  deleteSuccessFinished: PropTypes.func,
   forceRefresh: PropTypes.func,
   label: PropTypes.shape({
     heading: PropTypes.string,
@@ -573,7 +572,6 @@ RemoveResourceModal.propTypes = {
     primaryBtn: PropTypes.string
   }),
   locale: PropTypes.string,
-  mutateSuccessFinished: PropTypes.func,
   open: PropTypes.bool,
   resourceType: PropTypes.object,
   submitDeleteSuccess: PropTypes.func,
@@ -583,22 +581,11 @@ RemoveResourceModal.propTypes = {
 const mapStateToProps = () => ({})
 
 const mapDispatchToProps = (dispatch, ownProps) => {
-  let resourceType = ownProps.resourceType
-  if (
-    resourceType &&
-    resourceType.name === RESOURCE_TYPES.HCM_APPLICATIONS.name
-  ) {
-    resourceType = RESOURCE_TYPES.QUERY_APPLICATIONS
-  }
-
   return {
-    forceRefresh: () => dispatch(forceResourceReload(resourceType)),
-    deleteSuccessFinished: resType =>
-      dispatch(delResourceSuccessFinished(resType)),
-    mutateSuccessFinished: resType =>
-      dispatch(mutateResourceSuccessFinished(resType)),
+    forceRefresh: () => dispatch(forceResourceReload(ownProps.resourceType)),
+    clearSuccessFinished: () => clearSuccessFinished(dispatch),
     submitDeleteSuccess: () =>
-      dispatch(receiveDelResource(ownProps.data, resourceType, {}))
+      dispatch(receiveDelResource(ownProps.data, ownProps.resourceType, {}))
   }
 }
 
