@@ -1,28 +1,28 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2018, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 import React from 'react'
 import {
   createEditLink,
   getAge,
   getChannelLabel,
-  getClusterCount,
   getEditLink,
   getSearchLink,
   normalizeChannelType,
   CHANNEL_TYPES
 } from '../../lib/client/resource-helper'
-import { cellWidth } from '@patternfly/react-table'
 import {
-  getClusterCounts,
-  createClustersText,
-  getEmptyMessage
-} from './hcm-subscription'
+  isSearchAvailable,
+  isYAMLEditAvailable
+} from '../../lib/client/search-helper'
+import { cellWidth } from '@patternfly/react-table'
+import { createClustersText, getEmptyMessage } from './hcm-subscription'
 import ChannelLabels from '../components/common/ChannelLabels'
 import msgs from '../../nls/platform.properties'
 
@@ -56,14 +56,16 @@ export default {
       msgKey: 'table.header.subscriptions',
       resourceKey: 'subscriptionCount',
       transformFunction: createSubscriptionsLink,
-      tooltipKey: 'table.header.channels.subscriptions.tooltip'
+      tooltipKey: 'table.header.channels.subscriptions.tooltip',
+      disabled: () => !isSearchAvailable()
     },
     {
       msgKey: 'table.header.clusters',
       resourceKey: 'clusterCount',
-      transformFunction: createClustersLink,
+      transformFunction: createClustersText,
       textFunction: createClustersText,
-      tooltipKey: 'table.header.channels.clusters.tooltip'
+      tooltipKey: 'table.header.channels.clusters.tooltip',
+      disabled: () => !isSearchAvailable()
     },
     {
       msgKey: 'table.header.created',
@@ -71,14 +73,21 @@ export default {
       transformFunction: getAge
     }
   ],
-  tableActions: [
-    {
+  tableActionsResolver: tableActionsResolver
+}
+
+function tableActionsResolver() {
+  const actions = []
+  if (isYAMLEditAvailable()) {
+    actions.push({
       key: 'table.actions.channels.edit',
       link: {
         url: getEditLink
       }
-    },
-    {
+    })
+  }
+  if (isSearchAvailable()) {
+    actions.push({
       key: 'table.actions.channels.search',
       link: {
         url: item =>
@@ -91,13 +100,14 @@ export default {
             }
           })
       }
-    },
-    {
-      key: 'table.actions.channels.remove',
-      modal: true,
-      delete: true
-    }
-  ]
+    })
+  }
+  actions.push({
+    key: 'table.actions.channels.remove',
+    modal: true,
+    delete: true
+  })
+  return actions
 }
 
 function createSubscriptionsLink(item) {
@@ -115,18 +125,6 @@ function createSubscriptionsLink(item) {
   return item.subscriptionCount === 0 ? item.subscriptionCount : '-'
 }
 
-function createClustersLink(item, locale) {
-  const { remoteCount, localPlacement } = getClusterCounts(item)
-  return getClusterCount({
-    locale,
-    remoteCount,
-    localPlacement,
-    name: item.name,
-    namespace: item.namespace,
-    kind: 'placementrule'
-  })
-}
-
 function getChannels(item = {}, locale = '') {
   return (
     <ChannelLabels
