@@ -1,11 +1,12 @@
-/*******************************************************************************
+/** *****************************************************************************
  * Licensed Materials - Property of IBM
  * (c) Copyright IBM Corporation 2017, 2019. All Rights Reserved.
- * Copyright (c) 2020 Red Hat, Inc.
  *
  * US Government Users Restricted Rights - Use, duplication or disclosure
  * restricted by GSA ADP Schedule Contract with IBM Corp.
  *******************************************************************************/
+// Copyright (c) 2020 Red Hat, Inc.
+// Copyright Contributors to the Open Cluster Management project
 /*
 Since these selectors are common (i.e used across different components and different parts of the store)
 we have to create unique selectors each invocation and the selectors need additional metata data sent
@@ -88,7 +89,7 @@ const makeGetTransformedItemsSelector = resourceType => {
       item.transformed = transformed;
       // Augment with extra fields
       ['kind', 'apiVersion'].forEach(property => {
-        if (resourceType[property]) {
+        if (!item[property] && resourceType[property]) {
           item[property] = resourceType[property]
         }
       })
@@ -171,13 +172,15 @@ export const resourceReducerFunction = (state = INITIAL_STATE, action) => {
     return Object.assign({}, state, {
       status: Actions.REQUEST_STATUS.DONE,
       items: action.items,
-      resourceVersion: action.resourceVersion
+      resourceVersion: action.resourceVersion,
+      responseTime: Date.now()
     })
   }
   case Actions.RESOURCE_RECEIVE_FAILURE:
     return Object.assign({}, state, {
       status: Actions.REQUEST_STATUS.ERROR,
-      err: action.err
+      err: action.err,
+      responseTime: Date.now()
     })
   case Actions.RESOURCE_RECEIVE_NOT_FOUND:
     return Object.assign({}, state, {
